==> bgp-path-selection-mode-0.9.0-sources.jar: org/opendaylight/protocol/bgp/mode/impl/add/AddPathBestPath.java <==
/*
 * Copyright (c) 2015 Cisco Systems, Inc. and others.  All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v1.0 which accompanies this distribution,
 * and is available at http://www.eclipse.org/legal/epl-v10.html
 */
package org.opendaylight.protocol.bgp.mode.impl.add;

import static java.util.Objects.requireNonNull;

import com.google.common.base.MoreObjects.ToStringHelper;
import com.google.common.primitives.UnsignedInteger;
import javax.annotation.Nonnull;
import org.opendaylight.protocol.bgp.mode.api.BestPathState;
import org.opendaylight.protocol.bgp.mode.spi.AbstractBestPath;
import org.opendaylight.protocol.bgp.rib.spi.RouterIds;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bgp.rib.rev171207.PeerId;

public final class AddPathBestPath extends AbstractBestPath {
    private final RouteKey routeKey;
    private final int offsetPosition;
    private final long pathId;

    public AddPathBestPath(@Nonnull final BestPathState state, @Nonnull final RouteKey key, final int offsetPosition,
            final Long pathId) {
        super(state);
        this.routeKey = requireNonNull(key);
        this.offsetPosition = offsetPosition;
        this.pathId = pathId;
    }

    public RouteKey getRouteKey() {
        return this.routeKey;
    }

    @Override
    protected ToStringHelper addToStringAttributes(final ToStringHelper toStringHelper) {
        toStringHelper.add("routeKey", this.routeKey);
        toStringHelper.add("state", this.state);
        toStringHelper.add("offsetPosition", this.offsetPosition);
        toStringHelper.add("pathId", this.pathId);
        return toStringHelper;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + this.routeKey.hashCode();
        result = prime * result + this.state.hashCode();
        return result;
    }

    @Override
    public boolean equals(final Object obj) {
        if (this == obj) {
            return true;
        }
        if (!(obj instanceof AddPathBestPath)) {
            return false;
        }
        final AddPathBestPath other = (AddPathBestPath) obj;
        if (!this.routeKey.equals(other.routeKey)) {
            return false;
        }
        /*
        We don't check offset position since it will change as new path is added, and we want to be able
        to use List comparison between old bestpath list and new best path list.
        */
        if (!this.state.equals(other.state)) {
            return false;
        }

        return this.pathId == other.pathId;
    }

    @Override
    public UnsignedInteger getRouterId() {
        return this.routeKey.getRouteId();
    }

    @Override
    public PeerId getPeerId() {
        return RouterIds.createPeerId(this.routeKey.getRouteId());
    }

    @Override
    public long getPathId() {
        return this.pathId;
    }
}

==> bgp-path-selection-mode-0.22.1-sources.jar: org/opendaylight/protocol/bgp/mode/impl/add/AddPathBestPath.java <==
/*
 * Copyright (c) 2015 Cisco Systems, Inc. and others.  All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v1.0 which accompanies this distribution,
 * and is available at http://www.eclipse.org/legal/epl-v10.html
 */
package org.opendaylight.protocol.bgp.mode.impl.add;

import static java.util.Objects.requireNonNull;

import com.google.common.base.MoreObjects.ToStringHelper;
import org.eclipse.jdt.annotation.NonNull;
import org.opendaylight.protocol.bgp.mode.api.BestPathState;
import org.opendaylight.protocol.bgp.mode.spi.AbstractBestPath;
import org.opendaylight.protocol.bgp.rib.spi.RouterId;
import org.opendaylight.yangtools.yang.common.Uint32;

public final class AddPathBestPath extends AbstractBestPath {
    private final @NonNull RouteKey routeKey;
    private final @NonNull Uint32 pathId;
    private final int offset;

    AddPathBestPath(final @NonNull BestPathState state, final @NonNull RouteKey key, final @NonNull Uint32 pathId,
            final int offset) {
        super(state);
        this.routeKey = requireNonNull(key);
        this.pathId = requireNonNull(pathId);
        this.offset = offset;
    }

    RouteKey getRouteKey() {
        return this.routeKey;
    }

    public int getOffset() {
        return offset;
    }

    @Override
    protected ToStringHelper addToStringAttributes(final ToStringHelper toStringHelper) {
        return super.addToStringAttributes(toStringHelper.add("routeKey", this.routeKey)
            .add("pathId", this.pathId)
            .add("offset", offset));
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + this.routeKey.hashCode();
        result = prime * result + this.state.hashCode();
        return result;
    }

    @Override
    public boolean equals(final Object obj) {
        if (this == obj) {
            return true;
        }
        if (!(obj instanceof AddPathBestPath)) {
            return false;
        }
        final AddPathBestPath other = (AddPathBestPath) obj;
        if (!this.routeKey.equals(other.routeKey)) {
            return false;
        }
        /*
        We don't check offset position since it will change as new path is added, and we want to be able
        to use List comparison between old bestpath list and new best path list.
        */
        if (!this.state.equals(other.state)) {
            return false;
        }

        return this.pathId.equals(other.pathId);
    }

    @Override
    public RouterId getRouterId() {
        return this.routeKey.getRouterId();
    }

    @Override
    public long getPathId() {
        // FIXME: this should return int bits...
        return this.pathId.longValue();
    }

    /**
     * Return the boxed value equivalent of {@link #getPathId()}. This class uses boxed instances internally, hence
     * this method exposes it.
     *
     * @return Path Id as a {@link Long}
     */
    @NonNull Uint32 getPathIdLong() {
        return this.pathId;
    }
}
